# Ncname

Prefix part of CURIE

URI: http://www.w3.org/2001/XMLSchema#string

* [base](https://w3id.org/linkml/base): NCName


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


